@@ -5,8 +5,8 @@
 ;; Author: Alvaro Ramirez https://xenodium.com
 ;; Package-Requires: ((emacs "28.1"))
 ;; URL: https://github.com/xenodium/time-zones
-;; Package-Version: 20260205.2126
-;; Package-Revision: 5513f14d857a
+;; Package-Version: 20260211.2330
+;; Package-Revision: 9f1326ad9e62
 
 ;; This package is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -379,7 +379,6 @@ Returns an alist of (IANA-TZ . POSIX-TZ) pairs."
     (seq-doseq (timezone time-zones-custom-timezones)
       (puthash (format "%s %s"
                        (or (map-elt timezone 'flag)
-                           (time-zones--country-flag (map-elt timezone 'timezone))
                            time-zones--fallback-flag)
                        (or (map-elt timezone 'city)
                            (map-elt timezone 'state)
@@ -605,7 +604,6 @@ and MAX-OFFSET-WIDTH."
                "☽" " ")
            (format-time-string "%R" local-time (map-elt city 'timezone))
            (or (map-elt city 'flag)
-               (time-zones--country-flag (map-elt city 'country))
                time-zones--fallback-flag)
            (propertize (or (map-elt city 'city)
                            (map-elt city 'state)
